@@ -8,7 +8,7 @@ fborm Module Documentation
 ===========================
 """
 
-__version__ = (0,2,6)
+__version__ = (0,2,7)
 __version_string__ = '.'.join(str(x) for x in __version__)
 
 __author__ = 'Doug Napoleone'
@@ -312,3 +312,15 @@ class FogBugzORM:
         """
         return listMilestones(self.fb, *args, **kwdargs)
         
+    def subscribe(self, ixBug, ixPerson=None):
+        """Wrapper around :py:func:`fborm.commands.subscribe` .
+        The first argument, the fogbugz instance, is supplied automatically.
+        """
+        return subscribe(self.fb, ixBug, ixPerson)
+    
+    def unsubscribe(self, ixBug, ixPerson=None):
+        """Wrapper around :py:func:`fborm.commands.unsubscribe` .
+        The first argument, the fogbugz instance, is supplied automatically.
+        """
+        return unsubscribe(self.fb, ixBug, ixPerson)
+        
\ No newline at end of file
